==> ajaxplorer-4.2.3.tbz: www/ajaxplorer/plugins/auth.ftp/i18n/conf/en.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
$mess=array(
"FTP Authentification" => "FTP Authentification",
"Authenticate user directly to an FTP server, and connect him to this server." => "Authenticate user directly to an FTP server, and connect him to this server.",
"FTP Login Screen" => "FTP Login Screen",
"Whether to display a generic 'FTP connexion' dialog at startup (allowing the user to enter his own host/port data) or the standard login dialog." => "Whether to display a generic 'FTP connexion' dialog at startup (allowing the user to enter his own host/port data) or the standard login dialog.",
"Repository" => "Repository",
"Id of the repository to use for testing connexion" => "Id of the repository to use for testing connexion",
"Admin user" => "Admin user",
"The ID of an existing admin for Ajaxplorer (using conf.serial)" => "The ID of an existing admin for Ajaxplorer (using conf.serial)",
);
?>

==> ajaxplorer-5.0.1.tbz: www/ajaxplorer/plugins/auth.ftp/i18n/conf/en.php <==
<?php
/*
* Copyright 2007-2011 Charles du Jeu <contact (at) cdujeu.me>
* This file is part of AjaXplorer.
*
* AjaXplorer is free software: you can redistribute it and/or modify
* it under the terms of the GNU Affero General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* AjaXplorer is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
* along with AjaXplorer.  If not, see <http://www.gnu.org/licenses/>.
*
* The latest code can be found at <http://www.ajaxplorer.info/>.
*/
$mess=array(
"FTP Authentification" => "FTP Authentification",
"Authenticate user directly to an FTP server, and connect him to this server." => "Authenticate user directly to an FTP server, and connect him to this server.",
"FTP Login Screen" => "FTP Login Screen",
"Whether to display a generic 'FTP connexion' dialog at startup (allowing the user to enter his own host/port data) or the standard login dialog." => "Whether to display a generic 'FTP connexion' dialog at startup (allowing the user to enter his own host/port data) or the standard login dialog.",
"Repository" => "Repository",
"Id of the repository to use for testing connexion" => "Id of the workspace to use for testing connexion",
"Admin user" => "Admin user",
"The ID of an existing admin for Ajaxplorer (using conf.serial)" => "The ID of an existing admin for Ajaxplorer (using conf.serial)",
);
?>
